<?php
include ("slooze_local.php");
page_open(array("sess" => "Tof_Session",
				"auth" => "Tof_Auth"));
$tof = new MySlooze($auth->auth['uid'],false);
require_once("render/session.php");
$render = new BasicRender($tof);
$tof->setRender($render);
$vars = $tof->validateInputs();
updateSessionParameters($render,$vars);
$page = $tof->ct->getPage($vars['TopicID'],$vars['PageNum']);
if ($page) {
	require_once('pdf.php');
	$pdf = new PDF($tof);
	$pdf->addPage($page,$vars['Quality']);
	$pdf->toJpeg(72*$render->pageScale);
} else {
	$render->error("No such page ".$vars['PageNum']);
	require_once("render/page.php");
	renderMessagePage($render,$vars,$PHP_SELF);
}
// We do not close the page because of session concurrency issues:
// page_open may have read old values of session variables, and we must not save them
?>